@@ -32,6 +32,10 @@
 -- >   deriving (Semigroup, Monoid)
 -- >     via Fun (Coerce All Bool >>> Not >>> Coerce Bool Any)
 --
+-- > data T1 a = T1 [a] a
+-- >   deriving Generic
+-- >   deriving (Functor, Applicative, Monad, Foldable) via Fun1 (T1 ?-> Product [] Identity)
+--
 -- = Extensions to use this library
 --
 -- > {-# LANGUAGE DerivingVia, TypeOperators #-}
@@ -70,7 +74,7 @@ module DerivingViaFun
   , Adhoc
 
   -- * Higher-kinded types
-  , Fun1
+  , Fun1(..)
   , fun1
   , unfun1
   , Apply1
