@@ -8,6 +8,8 @@ module Main (main) where
 
 import DerivingViaFun
 import Data.Monoid (Sum(..), Any(..))
+import Data.Functor.Product (Product(..))
+import Data.Functor.Identity (Identity(..))
 import GHC.Generics (Generic)
 
 data T0 = T0 Int Bool
@@ -19,5 +21,9 @@ newtype All = All Bool
   deriving (Eq, Ord) via Fun (Coerce All Bool)
   deriving (Semigroup, Monoid) via Fun (Coerce All Bool >>> Not >>> Coerce Bool Any)
 
+data T1 a = T1 [a] a
+  deriving Generic
+  deriving (Functor, Applicative, Monad, Foldable) via Fun1 (T1 ?-> Product [] Identity)
+
 main :: IO ()
 main = pure ()
